package com.cuit.solarenergy.controller;


import com.cuit.solarenergy.base.annotation.AopLog;
import com.cuit.solarenergy.base.annotation.AuthToken;
import com.cuit.solarenergy.entity.vo.ret.RetResponse;
import com.cuit.solarenergy.entity.vo.ret.RetResult;
import com.cuit.solarenergy.exception.ParamsException;
import com.cuit.solarenergy.minio.BcException;
import com.cuit.solarenergy.minio.MinioInfo;
import com.cuit.solarenergy.minio.MinioService;
import com.cuit.solarenergy.utils.ErrorMessage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

@Api(tags = "11、minio模块")
@ApiSupport(order = 11)
@Slf4j
@RestController
@RequestMapping()
@Transactional(rollbackFor = Exception.class)
public class MinioController {
    public static final String BUCKET_NAME = "railway";
    @Resource
    private MinioService minioService;

    /**
     * @author: hpj
     * @date: 2022/6/27 1:03
     * @version: 1.0
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 1)
    @ApiOperation("1、上传文件到文件服务器")
    @PreAuthorize("hasAuthority('minio:upload')")
    @RequestMapping(value = "/minio/upload", method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<MinioInfo> upload(@RequestPart(value = "file") MultipartFile file) {
        try {
            MinioInfo appendixInfo = minioService.uploadFile(file);

            return RetResponse.makeOKRsp(appendixInfo);
        } catch (ParamsException p) {
            log.error(p.getMessage());
            return RetResponse.makeErrRsp("文件异常:" + p.getMessage());
        } catch (ErrorMessage | BcException e) {
            log.error(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        } catch (Exception e) {
            log.error("服务器异常......");
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常......");
        }
    }

    /**
     *方法功能：上传tif格式文件到服务器
     *
     * @param file
     * @date 2023/8/1 14:50
     * @author Tjb
     * @return
     */

    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 1)
    @ApiOperation("4、上传tif格式文件到服务器")
    @PreAuthorize("hasAuthority('minio:uploadForTif')")
    @RequestMapping(value = "/minio/uploadForTif", method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<MinioInfo> uploadForTif(@RequestPart(value = "file") MultipartFile file) {
        try {
            MinioInfo appendixInfo = minioService.uploadForTif(file, null, null, null, null, null, null, 1);

            return RetResponse.makeOKRsp(appendixInfo);
        } catch (ParamsException p) {
            log.error(p.getMessage());
            return RetResponse.makeErrRsp("文件异常:" + p.getMessage());
        } catch (ErrorMessage | BcException e) {
            log.error(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        } catch (Exception e) {
            log.error("服务器异常......");
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常......");
        }
    }


    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 2)
    @ApiOperation("2、上传文件到文件服务器（批量)")
    @PreAuthorize("hasAuthority('minio:batchUpload')")
    @RequestMapping(value = "/minio/batchUpload", method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<List<MinioInfo>> batchUpload(@RequestParam("files") MultipartFile[] files) {
        try {
            List<MinioInfo> appendixInfos = minioService.batchUploadFile(files);
            return RetResponse.makeOKRsp(appendixInfos);
        } catch (ErrorMessage | BcException e) {
            log.error(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        } catch (Exception e) {
            log.error("服务器异常......");
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常......");
        }
    }

    /**
     * @author: ASUS
     * @date: 2022/09/20 11:13
     * @version: 1.0
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 3)
    @ApiOperation("3、批量删除附件")
    @PreAuthorize("hasAuthority('minio:deleteAppendix')")
    @RequestMapping(value = "/minio/deleteAppendix", method = {RequestMethod.DELETE})
    @ApiImplicitParam(name = "attachmentIds", value = "附件id(多个,隔开)", required = true, dataTypeClass = String.class, paramType = "query")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> deleteAppendix(String attachmentIds) {
        Boolean flag = false;
        try {
            flag = minioService.deleteAppendix(attachmentIds);
            return RetResponse.makeOKRsp(flag);
        } catch (ParamsException | ErrorMessage p) {
            log.error(p.getMessage());
            return RetResponse.makeErrRsp(p.getMessage());
        } catch (Exception e) {
            log.error("服务器异常......");
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常......");
        }
    }

    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 3)
    @ApiOperation("4、下载文件")
    @PreAuthorize("hasAuthority('minio:downloadFile')")
    @RequestMapping(value = "/minio/downloadFile", method = {RequestMethod.DELETE})
    @ApiImplicitParam(name = "filenames", value = "文件名", required = true, dataTypeClass = String.class, paramType = "query")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> downloadFile(String filename, HttpServletResponse response) {
        if (!StringUtils.isEmpty(filename)) {
            try {
                minioService.downloadFile(filename, response);
                return RetResponse.makeOKRsp();
            }catch (BcException e) {
                return RetResponse.makeErrRsp(e.getMessage());
            }
        }
        return RetResponse.makeErrRsp("没有可下载文件");
    }
}
