package com.cuit.solarenergy.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.cuit.solarenergy.base.BasePageQuery;
import com.cuit.solarenergy.base.annotation.AopLog;
import com.cuit.solarenergy.base.annotation.AuthToken;
import com.cuit.solarenergy.config.MapConfig;
import com.cuit.solarenergy.entity.TSiteBaseInfo;
import com.cuit.solarenergy.entity.TStreamBaseInfo;
import com.cuit.solarenergy.entity.vo.ret.*;
import com.cuit.solarenergy.exception.ParamsException;
import com.cuit.solarenergy.mapper.TMinioMapper;
import com.cuit.solarenergy.mapper.TSiteBaseInfoMapper;
import com.cuit.solarenergy.mapper.TStreamBaseInfoMapper;
import com.cuit.solarenergy.minio.MinioServer;
import com.cuit.solarenergy.service.MonitoringDataService;
import com.cuit.solarenergy.vo.SiteBaseInfo;
import com.cuit.solarenergy.vo.SitesInfoForOne;
import com.cuit.solarenergy.vo.SitesInfosForOne;
import com.cuit.solarenergy.vo.param.SiteInfoParams;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Author: Tjb
 * @CreateTime: 2023-06-17  09:34
 * @Description: 监测数据模块controller
 * @Version: 1.0
 */

@Api(tags = "3、监测数据模块")
@ApiSupport(order = 3)
@Slf4j
@RestController()
@Transactional(rollbackFor = Exception.class)
public class MonitoringDataController {

    @Resource
    private MonitoringDataService monitoringDataService;


    @Resource
    private TStreamBaseInfoMapper tStreamBaseInfoMapper;
    @Resource
    private TSiteBaseInfoMapper tSiteBaseInfoMapper;

    @Resource
    private TMinioMapper tMinioMapper;

    @Resource
    private MinioServer minioServer;

    @Resource
    private MapConfig mapConfig;

    /**
     *方法功能：根据某一个水质参数查询当前年份所有站点的相关信息
     *
     * @param waterQualityParameter
     * @date 2023/6/19 14:21
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 1)
    @ApiOperation("1、根据某一个水质参数查询当前年份所有站点的相关信息")
    @PreAuthorize("hasAuthority('monitoring:getAllSiteForOne')")
    @RequestMapping(value = "/monitoring/getAllSiteForOne",method = {RequestMethod.GET})
    @ApiImplicitParam(name = "waterQualityParameter", value = "水质参数（如叶绿素）", required = true, dataTypeClass = String.class, paramType = "query")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<List<SitesInfoForOne>> getAllSiteForOne(String waterQualityParameter){
        List<SitesInfoForOne> sitesInfoForOnes;
        try{
            sitesInfoForOnes = monitoringDataService.getAllSiteForOne(waterQualityParameter);
            return RetResponse.makeOKRsp(sitesInfoForOnes);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeRsp(500, "服务器错误...");
        }
    }

    /**
     *方法功能：根据站点id查询站点基本信息
     *
     * @param siteId
     * @date 2023/6/19 15:10
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 2)
    @ApiOperation("2、根据站点id查询站点基本信息")
    @PreAuthorize("hasAuthority('monitoring:getSiteBaseInfo')")
    @RequestMapping(value = "/monitoring/getSiteBaseInfo",method = {RequestMethod.GET})
    @ApiImplicitParam(name = "siteId", value = "站点id", required = true, dataTypeClass = String.class, paramType = "query")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<SiteBaseInfo> getSiteBaseInfoById(String siteId){
        SiteBaseInfo siteBaseInfo;
        try{
            siteBaseInfo = monitoringDataService.getSiteBaseInfoById(siteId);
            return RetResponse.makeOKRsp(siteBaseInfo);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeRsp(500, "服务器错误...");
        }
    }

    /**
     *方法功能：获取某一流域指定时间段指定水质参数所有采样点详情
     *
     * @param siteInfoParams
     * @date 2023/6/19 16:01
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 3)
    @ApiOperation("3、获取某一流域指定时间段指定水质参数所有采样点详情")
    @PreAuthorize("hasAuthority('monitoring:getStreamAllSitesInfosForOne')")
    @RequestMapping(value = "/monitoring/getStreamAllSitesInfosForOne",method = {RequestMethod.GET})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<PageVo<SitesInfosForOne>> getStreamAllSitesInfosForOne(SiteInfoParams siteInfoParams, BasePageQuery query){
        PageVo<SitesInfosForOne> sitesInfosForOneList;
        try{
            sitesInfosForOneList = monitoringDataService.getStreamAllSitesInfosForOne(siteInfoParams,query);
            return RetResponse.makeOKRsp(sitesInfosForOneList);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeRsp(500, "服务器错误...");
        }
    }

    /**
     *方法功能：获取站点的所有图片
     *
     * @param siteId
     * @date 2023/7/3 11:37
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 4)
    @ApiOperation("4、获取站点的所有图片")
    @PreAuthorize("hasAuthority('monitoring:getSitePictures')")
    @RequestMapping(value = "/monitoring/getSitePictures",method = {RequestMethod.GET})
    @ApiImplicitParam(name = "siteId",value = "站点id",required = true,dataTypeClass = String.class,paramType = "query")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<PageVo<String>> getSitePictures(String siteId, BasePageQuery query){
        PageVo<String> page;
        try{
            page = monitoringDataService.getSitePictures(siteId,query);
            return RetResponse.makeOKRsp(page);
        }catch (ParamsException p) {
            return RetResponse.makeRsp(500, p.getMsg());
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeRsp(500, "服务器错误...");
        }
    }

    /**
     *方法功能：获取站点的所有视频
     *
     * @param siteId
     * @date 2023/7/3 11:37
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 5)
    @ApiOperation("5、获取站点的所有视频")
    @PreAuthorize("hasAuthority('monitoring:getSiteVideos')")
    @RequestMapping(value = "/monitoring/getSiteVideos",method = {RequestMethod.GET})
    @ApiImplicitParam(name = "siteId",value = "站点id",required = true,dataTypeClass = String.class,paramType = "query")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<PageVo<String>> getSiteVideos(String siteId, BasePageQuery query){
        PageVo<String> page;
        try{
            page = monitoringDataService.getSiteVideos(siteId,query);
            return RetResponse.makeOKRsp(page);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeRsp(500, "服务器错误...");
        }

    }
    /**
     *方法功能：获取监测数据首页指定流域指定水质参数当前年的站点信息List
     *
     * @param streamName 流域名称
     * @param indexName 水质参数名称
     * @date 2023/7/15 14:27 
     * @author Tjb
     * @return 
     */ 
    
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 6)
    @ApiOperation("6、获取监测数据首页指定流域指定水质参数当前年的站点信息List")
    @PreAuthorize("hasAuthority('monitoring:getMonitorSitesList')")
    @RequestMapping(value = "/monitoring/getMonitorSitesList",method = {RequestMethod.GET})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "streamName",value = "流域名称",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "indexName",value = "水质参数名称",required = true,dataTypeClass = String.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<List<MonitorSitesVo>> getMonitorSitesList(String streamName, String indexName){
        List<MonitorSitesVo> monitorSitesVoList;
        try{
            monitorSitesVoList = monitoringDataService.getMonitorSitesList(streamName,indexName);
            return RetResponse.makeOKRsp(monitorSitesVoList);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器错误...");
        }
    }


    /**
     *方法功能：返回图层URL和bbox
     *
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 7)
    @ApiOperation("7、返回图层URL和bbox")
    @PreAuthorize("hasAuthority('monitoring:getGeoserverIdAndBbox')")
    @RequestMapping(value = "/monitoring/getGeoserverIdAndBbox",method = {RequestMethod.GET})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "streamCode",value = "流域代码",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "typeCode",value = "数据类型代码（UAV、SAT等）",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "dataCode",value = "数据代码（如DOM、IR、NIR等）",required = true,dataTypeClass = String.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
//    public RetResult<List<MonitorGeoURLAndBboxVoRet>> getGeoserverIdAndBbox(String streamCode, String typeCode, String dataCode){
    public RetResult<Object> getGeoserverIdAndBbox(String streamCode, String typeCode, String dataCode){
        // 返回地形图相关数据
        if (dataCode.equals("MAP")) {
            return RetResponse.makeOKRsp(mapConfig);
        }
        // 返回其他数据
        List<MonitorGeoURLAndBboxVoRet> monitorGeoURLAndBboxVoRetList;
        try{
            monitorGeoURLAndBboxVoRetList = monitoringDataService.getGeoserverIdAndBbox(streamCode, typeCode, dataCode);
            return RetResponse.makeOKRsp(monitorGeoURLAndBboxVoRetList);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：新增流域
     *
     * @param streamCode
     * @param streamName
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 8)
    @ApiOperation("8、新增流域")
    @PreAuthorize("hasAuthority('monitoring:addStream')")
    @RequestMapping(value = "/monitoring/addStream",method = {RequestMethod.POST})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "streamCode",value = "流域代码",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "streamName",value = "流域名称",required = true,dataTypeClass = String.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> addStream(String streamCode, String streamName){
        try{
            Boolean addSuccess = monitoringDataService.addStream(streamCode,streamName);
            return RetResponse.makeOKRsp(addSuccess);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：新增站点
     *
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 9)
    @ApiOperation("9、新增站点")
    @PreAuthorize("hasAuthority('monitoring:addSite')")
    @RequestMapping(value = "/monitoring/addSite",method = {RequestMethod.POST})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "stationNo",value = "站点名称",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "streamCode",value = "站点所属流域编号",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "lon",value = "经度",required = true,dataTypeClass = Double.class,paramType = "query"),
            @ApiImplicitParam(name = "lat",value = "维度",required = true,dataTypeClass = Double.class,paramType = "query"),
            @ApiImplicitParam(name = "relativeSiteLocation",value = "相对站点位置",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "relativeSiteDistance",value = "相对站点距离",required = true,dataTypeClass = Double.class,paramType = "query"),
            @ApiImplicitParam(name = "distance",value = "距离施工点距离",required = true,dataTypeClass = Integer.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> addSite(String stationNo, String streamCode, Double lon, Double lat, String relativeSiteLocation, Double relativeSiteDistance, Integer distance){
        try{
            Boolean addSuccess = monitoringDataService.addSite(stationNo, streamCode, lon, lat, relativeSiteLocation, relativeSiteDistance, distance);
            return RetResponse.makeOKRsp(addSuccess);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：修改流域
     *
     * @param streamCode
     * @param streamName
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 10)
    @ApiOperation("10、修改流域")
    @PreAuthorize("hasAuthority('monitoring:editStream')")
    @RequestMapping(value = "/monitoring/editStream",method = {RequestMethod.PUT})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "streamCode",value = "流域代码（不允许修改，呈灰色）",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "streamName",value = "流域名称",required = true,dataTypeClass = String.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> editStream(String streamCode, String streamName){
        try{
            Boolean editSuccess = monitoringDataService.editStream(streamCode,streamName);
            return RetResponse.makeOKRsp(editSuccess);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：修改站点
     *
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 11)
    @ApiOperation("11、修改站点")
    @PreAuthorize("hasAuthority('monitoring:editSite')")
    @RequestMapping(value = "/monitoring/editSite",method = {RequestMethod.PUT})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "stationNo",value = "站点代码（不允许修改，呈灰色）",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "lon",value = "经度",required = true,dataTypeClass = Double.class,paramType = "query"),
            @ApiImplicitParam(name = "lat",value = "纬度",required = true,dataTypeClass = Double.class,paramType = "query"),
            @ApiImplicitParam(name = "relativeSiteLocation",value = "相对站点位置",required = true,dataTypeClass = String.class,paramType = "query"),
            @ApiImplicitParam(name = "relativeSiteDistance",value = "相对站点距离",required = true,dataTypeClass = Double.class,paramType = "query"),
            @ApiImplicitParam(name = "distance",value = "距离施工点距离",required = true,dataTypeClass = Integer.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> editSite(String stationNo, Double lon, Double lat, String relativeSiteLocation, Double relativeSiteDistance, Integer distance){
        try{
            Boolean editSuccess = monitoringDataService.editSite(stationNo, lon, lat, relativeSiteLocation, relativeSiteDistance, distance);
            return RetResponse.makeOKRsp(editSuccess);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：删除流域
     *
     * @param streamCode
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 12)
    @ApiOperation("12、删除流域")
    @PreAuthorize("hasAuthority('monitoring:deleteStream')")
    @RequestMapping(value = "/monitoring/deleteStream",method = {RequestMethod.PUT})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "streamCode",value = "流域代码",required = true,dataTypeClass = String.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> deleteStream(String streamCode){
        try{
            LambdaQueryWrapper<TStreamBaseInfo> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(TStreamBaseInfo::getStreamCode, streamCode);
            int delete = tStreamBaseInfoMapper.delete(queryWrapper);
            return RetResponse.makeOKRsp(delete != 0);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：删除站点
     *
     * @param stationNo
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 13)
    @ApiOperation("13、删除站点")
    @PreAuthorize("hasAuthority('monitoring:deleteSite')")
    @RequestMapping(value = "/monitoring/deleteSite",method = {RequestMethod.PUT})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "stationNo",value = "站点代码",required = true,dataTypeClass = String.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> deleteSite(String stationNo){
        try{
            LambdaQueryWrapper<TSiteBaseInfo> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(TSiteBaseInfo::getStationNo, stationNo);
            int delete = tSiteBaseInfoMapper.delete(queryWrapper);
            return RetResponse.makeOKRsp(delete != 0);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：删除图片或视频
     *
     * @param id
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 15)
    @ApiOperation("15、删除图片或视频")
    @PreAuthorize("hasAuthority('monitoring:deleteFile')")
    @RequestMapping(value = "/monitoring/deleteFile",method = {RequestMethod.PUT})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id",value = "id",required = true,dataTypeClass = String.class,paramType = "query")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> deleteFile(Integer id){
        try{
            int delete = tMinioMapper.deleteById(id);
            return RetResponse.makeOKRsp(delete != 0);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }

    /**
     *方法功能：返回地形图信息
     *
     * @date 2023/8/9 21:49
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 16)
    @ApiOperation("16、返回地形图信息")
    @PreAuthorize("hasAuthority('monitoring:getSiteBaseInfo')")
    @RequestMapping(value = "/monitoring/getMapInformation",method = {RequestMethod.GET})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<MapConfig> getMapInformation(){
        try{
            return RetResponse.makeOKRsp(mapConfig);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }
}

















