package com.cuit.solarenergy.controller;

import com.cuit.solarenergy.base.BasePageQuery;
import com.cuit.solarenergy.base.annotation.AopLog;
import com.cuit.solarenergy.base.annotation.AuthToken;
import com.cuit.solarenergy.entity.User;
import com.cuit.solarenergy.entity.vo.req.SystemManageModelVoReq;
import com.cuit.solarenergy.entity.vo.req.UserUpdateVoReq;
import com.cuit.solarenergy.entity.vo.ret.*;
import com.cuit.solarenergy.exception.ParamsException;
import com.cuit.solarenergy.minio.BcException;
import com.cuit.solarenergy.minio.MinioInfo;
import com.cuit.solarenergy.minio.MinioService;
import com.cuit.solarenergy.service.SystemManageService;
import com.cuit.solarenergy.utils.ErrorMessage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * @Author: Tjb
 * @CreateTime: 2023-07-17  10:02
 * @Description: 系统管理模块
 * @Version: 1.0
 */
@Api(tags = "8、系统管理模块")
@ApiSupport(order = 8)
@Slf4j
@RestController()
@Transactional(rollbackFor = Exception.class)
public class SystemManageController {

    @Autowired
    private SystemManageService systemManageService;

    @Autowired
    private MinioService minioService;

    /**
     * 方法功能：获取系统管理-角色管理list
     *
     * @param
     * @return
     * @date 2023/7/17 10:07
     * @author Tjb
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 1)
    @PreAuthorize("hasAuthority('system:manage:getRoleManageList')")
    @ApiOperation("1、获取角色管理list")
    @RequestMapping(value = "/system/manage/getRoleManageList", method = {RequestMethod.GET})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<List<RoleManageVoRet>> getRoleManageList() {
        List<RoleManageVoRet> roleManageVoRetList;
        try {
            roleManageVoRetList = systemManageService.getRoleManageList();
            return RetResponse.makeOKRsp(roleManageVoRetList);
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeRsp(500, "服务器错误...");
        }
    }


    /**
     * 方法功能：获取系统管理-用户管理list
     *
     * @param query
     * @return
     * @date 2023/7/17 14:57
     * @author Tjb
     */

    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 2)
    @PreAuthorize("hasAuthority('system:manage:getUserManageList')")
    @ApiOperation("2、获取用户管理list")
    @RequestMapping(value = "/system/manage/getUserManageList", method = {RequestMethod.GET})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<PageVo<UserManageVoRet>> getUserManageList(BasePageQuery query) {
        PageVo<UserManageVoRet> userManageVoRetPageVo;
        try {
            userManageVoRetPageVo = systemManageService.getUserManageList(query);
            return RetResponse.makeOKRsp(userManageVoRetPageVo);
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常.....");
        }
    }


    /**
     * 方法功能：系统管理-用户管理-更新用户信息
     *
     * @param userUpdateVoReq
     * @return
     * @date 2023/7/17 15:40
     * @author Tjb
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 3)
    @PreAuthorize("hasAuthority('system:manage:updateUser')")
    @ApiOperation("3、更新用户信息")
    @RequestMapping(value = "/system/manage/updateUser", method = {RequestMethod.PUT})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> updateUser(@RequestBody UserUpdateVoReq userUpdateVoReq) {
        if (Objects.isNull(userUpdateVoReq)) {
            return RetResponse.makeErrRsp("更新用户为空！");
        }
        Boolean isUpdateSuccessful;
        try {
            isUpdateSuccessful = systemManageService.updateUser(userUpdateVoReq);
            return RetResponse.makeOKRsp(isUpdateSuccessful);
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常.....");
        }
    }

    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 4)
    @PreAuthorize("hasAuthority('system:manage:changePassword')")
    @ApiOperation("4、修改用户密码")
    @RequestMapping(value = "/system/manage/changePassword", method = {RequestMethod.PUT})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userName", value = "用户名", required = true, paramType = "query", dataType = "string"),
            @ApiImplicitParam(name = "oldPassword", value = "原始密码", paramType = "query", dataType = "string"),
            @ApiImplicitParam(name = "newPassword", value = "新密码（8个或以上字符，并且要求至少包含一个小写字母，一个大写字母，一个数字和一个特殊字符）", paramType = "query", dataType = "string")
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> changePassword(String userName, String oldPassword, String newPassword) {
        if (StringUtils.isEmpty(userName)) {
            return RetResponse.makeErrRsp("更新用户名为空！");
        }
        if (StringUtils.isEmpty(newPassword)) {
            return RetResponse.makeErrRsp("新密码为空！");
        }

        if (!systemManageService.checkPasswordComplexity(newPassword)) {
            return RetResponse.makeErrRsp("密码不符合要求，密码需要8个或以上字符，并且至少包含一个小写字母，一个大写字母，一个数字和一个特殊字符");
        }

        Boolean isUpdateSuccessful;
        try {
            isUpdateSuccessful = systemManageService.changeUserPassword(userName, oldPassword, newPassword);
            return RetResponse.makeOKRsp(isUpdateSuccessful);
        } catch (Exception e) {
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }


    /**
     * 方法功能：系统管理-用户管理-删除用户信息
     *
     * @param id 需要删除的用户id
     * @return
     * @date 2023/7/17 15:40
     * @author Tjb
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 5)
    @PreAuthorize("hasAuthority('system:manage:deleteUser')")
    @ApiOperation("5、删除用户信息")
    @RequestMapping(value = "/system/manage/deleteUser", method = {RequestMethod.DELETE})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> deleteUser(String id) {
        if (Objects.isNull(id)) {
            return RetResponse.makeErrRsp("id为空！");
        }
        Boolean isDeleteSuccessful;
        try {
            isDeleteSuccessful = systemManageService.deleteUser(id);
            return RetResponse.makeOKRsp(isDeleteSuccessful);
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常.....");
        }
    }

    /**
     * 方法功能：系统管理-用户管理-新增用户
     *
     * @param user
     * @return
     * @date 2023/7/17 15:40
     * @author Tjb
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 6)
    @PreAuthorize("hasAuthority('system:manage:addUser')")
    @ApiOperation("7、新增用户")
    @RequestMapping(value = "/system/manage/addUser", method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> addUser(@RequestBody User user) {
        if (Objects.isNull(user)) {
            return RetResponse.makeErrRsp("新增用户为空！");
        }
        Boolean isAddSuccessful;
        try {
            isAddSuccessful = systemManageService.addUser(user);
            return RetResponse.makeOKRsp(isAddSuccessful);
        } catch (RuntimeException e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp(e.getMessage());
        }catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常.....");
        }
    }


    /**
     * 方法功能：获取系统管理-用户管理关键字查询list
     *
     * @param query
     * @param keyWord 关键字
     * @return
     * @date 2023/7/17 19:51
     * @author Tjb
     */

    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 7)
    @PreAuthorize("hasAuthority('system:manage:getUserManageListBySearch')")
    @ApiOperation("7、用户管理关键字查询list")
    @RequestMapping(value = "/system/manage/getUserManageListBySearch", method = {RequestMethod.GET})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<PageVo<UserManageVoRet>> getUserManageListBySearch(BasePageQuery query, String keyWord) {
        PageVo<UserManageVoRet> userManageVoRetPageVo;
        try {
            userManageVoRetPageVo = systemManageService.getUserManageListBySearch(query,keyWord);
            return RetResponse.makeOKRsp(userManageVoRetPageVo);
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常.....");
        }
    }



    /**
     * 方法功能：获取用户角色list
     *
     * @return
     * @date 2023/7/17 19:51
     * @author Tjb
     */

    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 8)
    @PreAuthorize("hasAuthority('system:manage:getUserRole')")
    @ApiOperation("8、获取用户角色list")
    @RequestMapping(value = "/system/manage/getUserRole", method = {RequestMethod.GET})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<List<String>> getUserRole() {
        ArrayList<String> getUserRoleList;
        try {
            getUserRoleList = systemManageService.getUserRole();
            return RetResponse.makeOKRsp(getUserRoleList);
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常.....");
        }
    }
    /**
     *方法功能：保存模型参数
     *
     * @param systemManageModelVoReq
     * @date 2023/7/24 14:39
     * @author Tjb
     * @return
     */

    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 9)
    @PreAuthorize("hasAuthority('system:manage:saveModel')")
    @ApiOperation("9、保存模型参数")
    @RequestMapping(value = "/system/manage/saveModel", method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Boolean> saveModel(@RequestBody SystemManageModelVoReq systemManageModelVoReq){
        Boolean saveSuccessful;
        try {
            saveSuccessful = systemManageService.saveModel(systemManageModelVoReq);
            return RetResponse.makeOKRsp(saveSuccessful);
        } catch (Exception e) {
            e.printStackTrace();
            return RetResponse.makeErrRsp(e.getMessage());
        }
    }


    /**
     * @author: hpj
     * @date: 2022/6/27 1:03
     * @version: 1.0
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 10)
    @ApiOperation("10、上传图片和视频到文件服务器")
    @PreAuthorize("hasAuthority('minio:uploadForFile')")
    @RequestMapping(value = "/minio/uploadForFile", method = {RequestMethod.POST})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "streamName", value = "流域名称", paramType = "query", dataType = "string"),
            @ApiImplicitParam(name = "siteName", value = "站点名称", paramType = "query", dataType = "string"),
            @ApiImplicitParam(name = "type", value = "文件类型", paramType = "query", dataType = "string", required = true)
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<MinioInfo> uploadForFile(@RequestPart(value = "file") MultipartFile file, String streamName, String siteName, String type) {
        try {
            MinioInfo appendixInfo = minioService.uploadFile(file, streamName, siteName, type);

            return RetResponse.makeOKRsp(appendixInfo);
        } catch (ParamsException p) {
            log.error(p.getMessage());
            return RetResponse.makeErrRsp("文件异常:" + p.getMessage());
        } catch (ErrorMessage | BcException e) {
            log.error(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        } catch (Exception e) {
            log.error("服务器异常......");
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常......");
        }
    }

    /**
     * @author: hpj
     * @date: 2022/6/27 1:03
     * @version: 1.0
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 11)
    @ApiOperation("11、批量上传图片和视频到文件服务器")
    @PreAuthorize("hasAuthority('minio:uploadForFiles')")
    @RequestMapping(value = "/minio/uploadForFiles", method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<List<MinioInfo>> uploadForFiles(@RequestPart(value = "files") MultipartFile[] files) {
        try {
            List<MinioInfo> appendixInfos = minioService.uploadFiles(files);

            return RetResponse.makeOKRsp(appendixInfos);
        } catch (ParamsException p) {
            log.error(p.getMessage());
            return RetResponse.makeErrRsp("文件异常:" + p.getMessage());
        } catch (ErrorMessage | BcException e) {
            log.error(e.getMessage());
            return RetResponse.makeErrRsp(e.getMessage());
        } catch (Exception e) {
            log.error("服务器异常......");
            e.printStackTrace();
            return RetResponse.makeErrRsp("服务器异常......");
        }
    }

//    /**
//     * @author: hpj
//     * @date: 2022/6/27 1:03
//     * @version: 1.0
//     */
//    @AuthToken
//    @AopLog
//    @ApiOperationSupport(order = 10)
//    @ApiOperation("11、上传视频到文件服务器")
//    @PreAuthorize("hasAuthority('minio:uploadForVideo')")
//    @RequestMapping(value = "/minio/uploadForVideo", method = {RequestMethod.POST})
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "streamName", value = "流域名称", paramType = "query", dataType = "string"),
//            @ApiImplicitParam(name = "siteName", value = "站点名称", paramType = "query", dataType = "string")
//    })
//    @ApiResponses({
//            @ApiResponse(code = 200, message = "成功"),
//            @ApiResponse(code = 401, message = "访问未经授权"),
//            @ApiResponse(code = 403, message = "访问被禁止的"),
//            @ApiResponse(code = 404, message = "未找到访问接口"),
//            @ApiResponse(code = 500, message = "服务器内部错误"),
//            @ApiResponse(code = 900, message = "失败")
//    })
//    public RetResult<MinioInfo> uploadForVideo(@RequestPart(value = "file") MultipartFile file, String streamName, String siteName) {
//        try {
//            MinioInfo appendixInfo = minioService.uploadVideo(file, streamName, siteName);
//
//            return RetResponse.makeOKRsp(appendixInfo);
//        } catch (ParamsException p) {
//            log.error(p.getMessage());
//            return RetResponse.makeErrRsp("文件异常:" + p.getMessage());
//        } catch (ErrorMessage | BcException e) {
//            log.error(e.getMessage());
//            return RetResponse.makeErrRsp(e.getMessage());
//        } catch (Exception e) {
//            log.error("服务器异常......");
//            e.printStackTrace();
//            return RetResponse.makeErrRsp("服务器异常......");
//        }
//    }
}
