package com.cuit.solarenergy.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.cuit.solarenergy.base.annotation.AopLog;
import com.cuit.solarenergy.base.annotation.AuthToken;
import com.cuit.solarenergy.entity.Model;
import com.cuit.solarenergy.entity.vo.req.UAVDetectionReq;
import com.cuit.solarenergy.entity.vo.ret.*;
import com.cuit.solarenergy.service.ModelService;
import com.cuit.solarenergy.service.MonitorService;
import com.cuit.solarenergy.utils.Constant;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.constraints.NotNull;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * @Author: Tjb
 * @CreateTime: 2023-07-04  09:39
 * @Description: 无人机检测模块controller
 * @Version: 1.0
 */
@Api(tags = "4、无人机检测模块")
@ApiSupport(order = 4)
@Slf4j
@RestController()
@Transactional(rollbackFor = Exception.class)
public class UAVMonitorController {

    @Resource
    private MonitorService monitorService;

    @Resource
    private ModelService modelService;


    /**
     *方法功能：获取无人机监测模块原始影像数据列表
     *
     * @param uavDetectionReq
     * @date 2023/7/4 11:30
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 1)
    @ApiOperation("1、获取无人机监测模块原始影像数据列表")
    @PreAuthorize("hasAuthority('UAV:monitor:getUAVOrgDetectionData')")
    @RequestMapping(value = "/UAV/monitor/getUAVOrgDetectionData",method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Map<String, Object>> getUAVOrgDetectionData(@RequestBody UAVDetectionReq uavDetectionReq){
        Map<String, Object> map = new LinkedHashMap<>();
        PageVo<DetectionOrgRet> detectionOrgRet;
        try{
            //获取表头
            map.put("tableHead", Constant.getUavOrgTableHead());
            //获取数据
            detectionOrgRet = monitorService.getUAVOrgDetectionData(uavDetectionReq);
            map.put("data", detectionOrgRet);
            return RetResponse.makeOKRsp(map);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeRsp(500, e.getMessage());
        }
    }

    /**
     *方法功能：获取无人机监测模块反演数据数据列表
     *
     * @param uavDetectionReq
     * @date 2023/7/4 11:30
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 2)
    @ApiOperation("2、获取无人机监测模块反演数据数据列表")
    @PreAuthorize("hasAuthority('UAV:monitor:getUAVInvDetectionData')")
    @RequestMapping(value = "/UAV/monitor/getUAVInvDetectionData",method = {RequestMethod.POST})
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Map<String, Object>> getUAVInvDetectionData(@RequestBody UAVDetectionReq uavDetectionReq){
        Map<String, Object> map = new LinkedHashMap<>();
        PageVo<DetectionInvRet> detectionInvRet;
        try{
            //获取表头
            map.put("tableHead", Constant.getUavInvTableHead());
            //获取数据
            detectionInvRet = monitorService.getUAVInvDetectionData(uavDetectionReq);
            map.put("data", detectionInvRet);
            return RetResponse.makeOKRsp(map);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeRsp(500, e.getMessage());
        }
    }

    /**
     *方法功能：查询无人机反演模型参数
     *
     * @param parameterName
     * @date 2023/7/4 11:30
     * @author Tjb
     * @return
     */
    @AuthToken
    @AopLog
    @ApiOperationSupport(order = 3)
    @ApiOperation("3、查询无人机反演模型参数")
    @PreAuthorize("hasAuthority('UAV:monitor:getUAVInvDetectionData')")
    @RequestMapping(value = "/UAV/monitor/getUAVModelData",method = {RequestMethod.GET})
    @ApiImplicitParam(name = "parameterName", value = "参数名称", required = true, dataTypeClass = String.class, paramType = "query")
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功"),
            @ApiResponse(code = 401, message = "访问未经授权"),
            @ApiResponse(code = 403, message = "访问被禁止的"),
            @ApiResponse(code = 404, message = "未找到访问接口"),
            @ApiResponse(code = 500, message = "服务器内部错误"),
            @ApiResponse(code = 900, message = "失败")
    })
    public RetResult<Model> getUAVModelData(@NotNull String parameterName){
        try{
            LambdaQueryWrapper<Model> modelLambdaQueryWrapper = new LambdaQueryWrapper<>();
            modelLambdaQueryWrapper.eq(Model::getIndexName, parameterName)
                    .eq(Model::getTypeNumber, 1)
                    .orderByDesc(Model::getId)
                    .last("limit 1");
            Model model = modelService.getOne(modelLambdaQueryWrapper);
            return RetResponse.makeOKRsp(model);
        }catch (Exception e){
            e.printStackTrace();
            return RetResponse.makeRsp(500, e.getMessage());
        }
    }

}
