package com.cuit.solarenergy.service;

import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * GeoServer数据发布服务
 * @author cuitg -- ZengwuWang
 * @date 2023年07月25日 16:25
 */
@Service
public interface GeoServerPubService {
    /**
     * 发布Tif GeoServere服务并保存到数据库t_geoserverinfo
     * @param filePathName 文件名（带路径）geotiff格式
     * @return  保存到geoServer数据库中的序列，-1表示未成功
     */
    public Long pubGeoServerAndSavetoDB(String filePathName);


    /**
     * 发布Tif GeoServere服务并保存到数据库t_geoserverinfo
     * @param defstyles 缺省样式
     * @param filePathName 文件名（带路径）geotiff格式
     * @return  保存到geoServer数据库中的序列，-1表示未成功
     */
    public Long pubGeoServerAndSavetoDB(String defstyles, String filePathName);


    /**
     * 发布Tif GeoServere服务并保存到数据库t_geoserverinfo
     * @param defstyles 缺省样式
     * @param srs 指定坐标系 如：ESPG:3857
     * @param filePathName 文件名（带路径）geotiff格式
     * @return  保存到geoServer数据库中的序列，-1表示未成功
     */
    public Long pubGeoServerAndSavetoDB(String defstyles, String srs, String filePathName);

    /**
     * 通过geoinfo表ID拼接URL
     * @param pubinfoID 表中ID
     * @return
     */
    String getRasterWmsUrl(Long pubinfoID);

    /**
     * 通过geoinfo表ID拼接URL
     * @param pubinfoID 表中ID
     * @return
     */
    String getMapBox3857RasterWmsUrl(Long pubinfoID);

    /**
     * 通过geoinfo表ID拼接URL
     * @param pubinfoID 表中ID
     * @return
     */
    String getMapBox3857RasterWmsUrlByBaseInfo(Long pubinfoID);

    /**
     * 取栅格值
     * @param geoinfoids geoserverinfo表中的id列表
     * @param x 经度
     * @param y 纬度
     * @return 返回Map(Long, Double), key是传入的id， 值Value为Double.NaN时，表示无该图层或无该图层覆盖
     */
    Map<Long, Double> getRasterValue(List<Long> geoinfoids, double x, double y);



    /**
     * 取栅格值
     * @param geoinfoids geoserverinfo表中的id列表
     * @param srs 坐标系 如 EPSG:4326
     * @param x 坐标
     * @param y 坐标
     * @return 返回Map(Long, Double), key是传入的id， 值Value为Double.NaN时，表示无该图层或无该图层覆盖
     */
    Map<Long, Double> getRasterValue(List<Long> geoinfoids, String srs, double x, double y);


    /**
     * 从GeoServer中，取图片
     * @param geoinfoid  geoserverinfo表中的id
     * @param w 图片宽度
     * @param h 图片高度
     * @param outPngFileName 输出文件名（带路径及png后缀）
     * @return 成功与否
     */
    boolean getPng(Long geoinfoid, int w, int h, String outPngFileName);


    /**
     * 从GeoServer中，取图层的经纬度边框
     * @param geoinfoid  geoserverinfo表中的id
     * @return bbox字符串， 经度（小），纬度（小），经度（大），纬度（大）
     */
    String getLatLonBoundingBox(Long geoinfoid);

    /**
     * 删除工作空间的所有图层
     * @param workspace 工作区
     * @return
     */
    Boolean removeLayer(String workspace);

    /**
     * 删除指定图层
     * @param workspace 工作区
     * @param layer
     * @return
     */
    Boolean removeLayer(String workspace, String layer);

    /**
     * 删除匹配的多个图层
     * @param workspace 工作区
     * @param layerpattern 图层名称（部分）
     * @return
     */
    Boolean removeLayers(String workspace, String layerpattern);
}
