package com.cuit.solarenergy.service.impl;

import com.cuit.gis.analysis.spatialstatistics.RasterStatistic;
import com.cuit.gis.exception.GeoTiffException;
import com.cuit.gis.raster.GeoTiff;
import com.cuit.gis.raster.GridCoverageUtil;
import com.cuit.gis.raster.RasterBandExtraction;
import com.cuit.solarenergy.service.GeoTiffService;
import lombok.extern.slf4j.Slf4j;
import org.geotools.coverage.grid.GridCoverage2D;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.IOException;
import java.util.Map;

/**
 * Geotiff文件相关服务
 * @author cuitg -- ZengwuWang
 * @date 2023年08月02日 9:58
 */
@Service
@Slf4j
public class GeoTiffServiceImpl implements GeoTiffService {
    /**
     * 获取geotiff单波段文件中的最大、最小值等
     * @param pathFilename 文件名（带路径和后缀名）
     * @return 统计Map Key:"count"、"min"、"max"、"sum"、"avg"
     */
    @Override
    public Map<String, Double> getGeoTiffStatistic(String pathFilename) {
        return getGeoTiffStatistic(pathFilename, 0);
    }
    /**
     * 获取geotiff文件中的最大、最小值等
     * @param pathFileName 文件名（带路径和后缀名）
     * @param band 波段
     * @return 统计Map Key:"count"、"min"、"max"、"sum"、"avg"
     */
    @Override
    public Map<String, Double> getGeoTiffStatistic(String pathFileName, int band) {
        File file = new File(pathFileName);
        if (file.exists() && file.isFile()) {
            GeoTiff geoTiff = null;
            try {
                geoTiff = new GeoTiff(pathFileName);
                GridCoverage2D coverage = geoTiff.getCoverage();
                RasterStatistic rasterStatistic = new RasterStatistic();
                Map<String, Double> StatisticMap = rasterStatistic.statisticsRaster(coverage, 0);
                return StatisticMap;
            } catch (GeoTiffException e) {
                log.error("读geotiff时发生错误：" + e.getMessage());
                return null;
            } finally {
                if (geoTiff != null) {
                    geoTiff.close();
                }
            }

        }
        else {
            log.error("文件" +pathFileName + "不存在！");
            return null;
        }
    }

    /**
     * 提取geoServer中的某些波段生成新的文件
     * @param pathFileName 源文件名（带路径和后缀名）
     * @param targetFileName 目标文件名（带路径和后缀名）
     * @param bands 波段（从0开始），如0或1，2，3。
     * @return
     */
    @Override
    public boolean extractionGeoTiffBands(String pathFileName, String targetFileName, int ... bands) {
        File file = new File(pathFileName);
        if (file.exists() && file.isFile()) {
            GeoTiff geoTiff = null;
            try {
                geoTiff = new GeoTiff(pathFileName);
                GridCoverage2D coverage = geoTiff.getCoverage();
                RasterBandExtraction rasterBandExtraction = new RasterBandExtraction(coverage, bands);
                GridCoverage2D coveragetarget = rasterBandExtraction.extractionGridCoverage2DBand();
                GridCoverage2D coverageReader = GridCoverageUtil.writeGeoTiff(coveragetarget, targetFileName);
                return  (coverageReader!=null);
            } catch (GeoTiffException e) {
                log.error("读geotiff时发生错误：" + e.getMessage());
                return false;
            } catch (IOException e) {
                log.error("写geotiff文件"+targetFileName+"时发生错误：" + e.getMessage());
                return false;
            }finally {
                if (geoTiff != null) {
                    geoTiff.close();
                }
            }

        }
        else {
            log.error("文件" +pathFileName + "不存在！");
            return false;
        }
    }

    @Override
    public int getBands(String pathFileName) {
        //获取文件的波段数
        int fileBands = 0;
        GeoTiff geoTiff = null;
        try {
            geoTiff = new GeoTiff(pathFileName);
            fileBands = geoTiff.getBandcount();
            geoTiff = null;
        } catch (GeoTiffException e) {
            fileBands = 0;
        }finally {
            if (geoTiff != null) {
                geoTiff.close();
            }
        }
        return fileBands;
    }
}
