package com.cuit.solarenergy.utils;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.IOUtils;

import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
/**
 * 解压工具
 * @author cuitg -- ZengwuWang
 * @date 2024年09月01日 8:42
 */
@Slf4j
public class FileZipUtil {
    /**
     * 解压缩zip文件
     * @param zipFile zip源文件
     * @param dir     目标目录
     */
    public static void unzip(File zipFile, File dir) throws IOException {

        ZipInputStream zipIn = null;
        try {
            zipIn = new ZipInputStream(new BufferedInputStream(new FileInputStream(zipFile)));
            ZipEntry zipEntry = null;
            FileOutputStream fileOut = null;
            while ((zipEntry = zipIn.getNextEntry()) != null) {
                try {
                    File file = new File(dir, zipEntry.getName());
                    if (zipEntry.isDirectory()) {
                        // 若为目录
                        file.mkdirs();
                        continue;
                    }
                    // 对文件的处理
                    //如果指定文件的目录不存在,则创建之.
                    File parent = file.getParentFile();
                    if (!parent.exists()) {
                        parent.mkdirs();
                    }
                    fileOut = new FileOutputStream(file);
                    IOUtils.copy(zipIn, fileOut);
                } finally {
                    IOUtils.closeQuietly(fileOut);
                    if (zipIn != null) {
                        zipIn.closeEntry();
                    }
                }

            }
        } finally {
            IOUtils.closeQuietly(zipIn);
        }
    }

    public static List<File> getFiles(String directory, final String extension) {
        List<File> files = new ArrayList<>();
        File dir = new File(directory);

        // 递归获取所有文件
        File[] subFiles = dir.listFiles((dir1, name) -> name.toUpperCase().endsWith("." + extension.toUpperCase()));
        if (subFiles != null) {
            for (File file : subFiles) {
                files.add(file);
                if (file.isDirectory()) {
                    files.addAll(getFiles(file.getAbsolutePath(), extension));
                }
            }
        }
        return files;
    }

    /**
     * 根据文件目录及文件后缀名获取文件列表
     * 递归查找包含关键字的文件
     *
     * @param folder 文件所在目录
     * @param keyWord 文件后缀名
     * @return File[] 文件列表
     */
    public static File[] searchFile(File folder, final String keyWord) {
        // 运用内部匿名类获得文件
        File[] subFolders = folder.listFiles(new FileFilter() {
            // 实现FileFilter类的accept方法
            @Override
            public boolean accept(File pathname) {
                // 目录或文件包含关键字
                if (pathname.isDirectory()
                        || (pathname.isFile() && pathname.getName()
                        .toLowerCase()
                        .contains(keyWord.toLowerCase())))
                    return true;
                return false;
            }
        });
        List<File> result = new ArrayList<>();
        // 声明一个集合
        for (int i = 0; i < subFolders.length; i++) {
            // 循环显示文件夹或文件
            if (subFolders[i].isFile()) {
                // 如果是文件则将文件添加到结果列表中
                result.add(subFolders[i]);
            } else {
                // 如果是文件夹，则递归调用本方法，然后把所有的文件加到结果列表中
                File[] foldResult = searchFile(subFolders[i], keyWord);
                for (int j = 0; j < foldResult.length; j++) {// 循环显示文件
                    result.add(foldResult[j]);// 文件保存到集合中
                }
            }
        }
        // 声明文件数组，长度为集合的长度
        File files[] = new File[result.size()];
        // 集合数组化
        result.toArray(files);
        return files;
    }

    /**
     * 根据文件目录及文件后缀名获取文件名列表
     * @param mir 文件所在目录
     * @param str 文件后缀名
     * @return String[] 文件名列表
     */
    public static String[] getFileNameList(String mir, String str){
        // 默认目录
        File folder = new File(mir);
        // 如果文件夹不存在
        if (!folder.exists()) {
            log.error("目录不存在：" + folder.getAbsolutePath());
            return null;
        }
        // 调用方法获得文件数组
        File[] result = searchFile(folder, str);
        String[] filename = new String[result.length];
        for (int i = 0; i < result.length; i++) {
            File file = result[i];
            if(file != null || file.length()!=0 ){
                filename[i] = file.getAbsolutePath();
            }
        }
        return filename;
    }

    //测试压缩与解压
    public static void main(String args[])throws Exception{
        String[] fileNameList = getFileNameList("E:\\test", ".tif");
        for (int i = 0; i < fileNameList.length; i++) {
            log.error(fileNameList[i]);
        }
        //unzip(new File("E:\\test\\aaaa.zip"), new File("E:\\test\\bbb"));
    }
}
